#
# spec file for package growpart
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           growpart
Version:        0.33
Release:        2.2
Summary:        Grow a partition
License:        GPL-3.0-only
Group:          System/Management
URL:            https://github.com/canonical/cloud-utils
Source0:        https://github.com/canonical/cloud-utils/archive/refs/tags/%{version}.tar.gz#/cloud-utils-%{version}.tar.gz
Requires:       gptfdisk
Requires:       util-linux
BuildArch:      noarch

%description
Grow a partition. This is predominantly useful in the cloud when an instance is
started with a larger root partition than the image size. The root partition
can be expanded to take up the additional size.

%prep
%autosetup -p1 -n cloud-utils-%{version}

%build

%install
install -Dm0755 -t %{buildroot}%{_sbindir} bin/growpart
install -Dm0644 -t %{buildroot}%{_mandir}/man1 man/growpart.1
install -Dm0644 -t %{buildroot}/%{_defaultlicensedir}/growpart LICENSE

%files
%license LICENSE
%{_sbindir}/growpart
%{_mandir}/man1/*

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.33:
  * More busybox compatibility changes
  * growpart: Add support for overprovisioning (#35)
  * mount-image-callback: do not rely on udevadm
  * growpart: only run `udevadm` if it exists (#36) [oittaa]
  * growpart: detect whether blkid is util-linux version and
    act accordingly
  * growpart doesn't work when LANG=cs_CZ.UTF-8
  * growpart: change flock call to use short option for
    Busybox compatibility [Dermot Bradley]
  * growpart: Use LANG=C to parse sfdisk output
  * Fix bad variable use.
  * Whitespace cleanups.
  * Growpart fix undefined variable in growpart error message.
  * cloud-image-utils: Add depends on fdisk, drop e2fsprogs
  * growpart: add flock support to prevent udev races
  * Drop the python2 only cloud-utils-euca package and tools.
  * test-growpart: fix logic error resulting in test failure.
- fix URL (development moved to GitHub)
- use fully qualified urls for source validation
- drop licenseGPLv3.patch (upstream)
* Wed Aug  2 2023 Robert Schweikert <rjschwei@suse.com>
- Update to verion 0.32
  + Only listing growpart changes we do not ship other parts of the source
  + Growpart fix undefined variable in growpart error message. [Scott Moser]
  + Add test for growpart lvm resize. [Scott Moser]
  + Growpart: add support for resizing an lvm pv after growing the
    partition. [Scott Moser] (LP: #1799953)
  + growpart: parse the kernel version in a more robust way (#2)
    [Paride Legovini] (LP: #1881014)
  + growpart: Do not fail if only sgdisk is available. [Scott Moser]
  + growpart: Fix reading sector size with newer sgdisk versions.
    [Scott Moser]
  + growpart: Fail on unknown values of GROWPART_RESIZER. [Scott Moser]
  + growpart: add flock support to prevent udev races
    [Ryan Harper] (LP: #1834875)
  + test-growpart: fix logic error resulting in test failure.
    [Scott Moser] (LP: #1842682)
  + Fix race condition in test-growpart teardown seen on ppc64el.
    [Scott Moser] (LP: #1836593)
  + growpart: Fix bug when file image ends in a digit.
    [Scott Moser] (LP: #1835124)
* Thu Feb 27 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 0.31 (bsc#1164736)
  + mount-image-callback: mount with -o 'rw' or -o 'ro' (LP: #1663722)
  + mount-image-callback: run blockdev and udevadm settle on nbd devices.
    (LP: #1741096, 1741300)
  + mount-image-callback: Drop support for mounting lxd containers.
    (LP: #1715994)
  + growpart: fix bug that stopped GPT disks from being grown past 2TB.
    (LP: #1762748)
  + mount-image-callback: mention --help and -C/--cd-mountpoint in Usage
  + growpart: fix bug when resizing a middle partition with sgdisk
    (LP: #1706751) [Fred De Backer]
  + growpart: Resolve symbolic links before operating.
    [Kevin Locke] (LP: #1744406)
  + growpart: fix bug occurring if start sector and size were the same.
    [Lars Kellogg-Stedman] (LP: #1807171)
  + debian/control: drop Suggests on lxc1
  + debian/tests/control: add test growpart-start-matches-size.
  + White space cleanup.  Remove trailing space and tabs.
  + Move to git.
- drop licenseGPLv3.patch (upstream)
* Tue Oct 29 2019 Fabian Vogt <fvogt@suse.com>
- Clean growpart.spec:
  * Drop obsolete tags
  * Use install instead of mkdir+cp+chmod
  * Fix build on SLE 12 SP4
* Fri Oct 25 2019 Ignaz Forster <iforster@suse.com>
- Replaced hardcoded systemd paths with macros in spec file
* Thu Oct 24 2019 Marcus Schaefer <ms@suse.com>
- Reference entry for maintenance
  Tracker bug for the submission set to: bsc#1154357
* Thu Oct 17 2019 Marcus Schaefer <ms@suse.com>
- Deleted rootgrow source and sub-package build
  rootgrow is provided on github: https://github.com/SUSE-Enceladus/rootgrow
  and builds a standalone package now
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Thu Jun 21 2018 rjschwei@suse.com
- Support btrfs resize, handle ro setup in rootgrow (bsc#1097455, bsc#1098681)
* Wed Apr  4 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Wed Jan 24 2018 rjschwei@suse.com
- Split rootgrow and script and service into subpackage to retain
  dependency chain for growpart
* Mon Jan 22 2018 rjschwei@suse.com
- Update to version 0.30 (bsc#1064755)
  + improved error messages on failure.
  + ignore sfdisk failure in 2.28.1 when due to reread failing
  (LP: #1619285)
  + Add service file to start growpart via systemd
  + Add rootgrow script to wrap growpart
* Tue Sep 13 2016 rjschwei@suse.com
- Update to version 0.29 (bsc#998378)
  + fix use of partx for newer util-linux versions (LP: #1587971)
    [Lars Kellogg-Stedman]
  + fix some issues in error path reporting
  + capture output of 'partx --help' as older versions
    do not support that flag, and send output to stderr.
  + fix bug when growing partitions on disks > 2TB. (LP: #1259703)
  + run partx only on block devices (not files)
  + better --dry-run output for gpt disks, providing sgdisk command
    line that would be used.
  + support sfdisk >= 2.26, and support gpt partitions with sfdisk
* Tue Mar 18 2014 rschweikert@suse.com
- add patch licenseGPLv3.patch
  + no license file included in upstream release
    (https://bugs.launchpad.net/cloud-utils/+bug/1294338)
  + GPL v3 applies to growpart script, that is all we are distributing
    at the moment
- fix the Group, don't shout
* Mon Mar 17 2014 rschweikert@suse.com
- include in SLE 12 (FATE #315990, #315991, and 316167)
* Mon Mar 17 2014 rschweikert@suse.com
- Initial build
